Hydrator<T extends RelationalModel<T>> class

Constructors

Hydrator(T model, List<Map<String, dynamic>> rows)

Properties

hashCode int
The hash code for this object.
no setterinherited
model → T
final
rows List<Map<String, dynamic>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

first() Future<T?>
get() Future<List<T>>
include(List<String> relations) Hydrator<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited