RelationalDatabaseAdapter class abstract

Constructors

RelationalDatabaseAdapter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String table, {String? where, List? params}) Future
get(String table, {List<String>? select, bool distinct = false, List<String>? joins, String? where, List? params, List<String>? groupBy, String? orderBy, int? limit, int? offset}) Future<List<Map<String, dynamic>>>
insert(String table, Map<String, dynamic> values) Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
raw(String sql, [List? args]) Future<List<Map<String, dynamic>>>
toString() String
A string representation of this object.
inherited
update(String table, Map<String, dynamic> values, {String? where, List? params}) Future

Operators

operator ==(Object other) bool
The equality operator.
inherited